==> em_celery-0.1.42-py2.py3-none-any.whl: em_celery/tools/spree/amz_uploadable_products_formatter_from_file.py <==
# -*- coding: utf-8 -*-

import json

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.tools.amz_uploadable_products_formatter import AmzUploadableProductsFormatter
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service_config, get_product_service


@click.command('Filter Amazon uploadable product from Spapi.')
@click.option('-s', '--store_code', required=True, type=str)
@click.option('-m', '--marketplace', required=True, type=str, default='us', help='Amazon marketplace.')
@click.option('-o', '--output_path', required=True, type=str, help='Output file path')
@click.option('-so', '--source', required=True, type=str, help='Product source.')
@click.option('-sc', '--source_code', required=True, type=str, help='Product source code.')
@click.option('-sp', '--sku_prefix', type=str, default='', help='Current product sku prefix to replace.')
@click.argument('products_path')
def filter_products(store_code, output_path, products_path, source, source_code, marketplace, sku_prefix=''):
  init_db()

  if not products_path or not output_path:
    return

  products_path = os.path.abspath(os.path.expanduser(products_path))
  if not os.path.isfile(products_path):
    return

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  filter_cond = get_amz_offer_filter_config()
  offer_service_cfg = get_offer_service_config()
  offer_service = AmzOfferService(
    offer_service_cfg['host'], offer_service_cfg['port'],
    offer_service_cfg['user'], offer_service_cfg['password'], filter_cond)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 4.5,
    'transfer_cost': 12
  }

  marketplace = marketplace.lower()
  cfg = get_config()
  price_rules_cfg = cfg.get('price.rules.amz_{}'.format(marketplace), dict())
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  product_service = get_product_service()
  products_filter = AmzUploadableProductsFormatter(store_code, marketplace, product_service, offer_service, price_calculator, output_path, products_path, source, source_code, sku_prefix='')
  products_filter.run()


if __name__ == "__main__":
  filter_products()

==> em_celery-0.1.46-py2.py3-none-any.whl: em_celery/tools/spree/amz_uploadable_products_formatter_from_file.py <==
# -*- coding: utf-8 -*-

import json

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.tools.amz_uploadable_products_formatter import AmzUploadableProductsFormatter
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service_config, get_product_service


@click.command('Filter Amazon uploadable product from Spapi.')
@click.option('-s', '--store_code', required=True, type=str)
@click.option('-m', '--marketplace', required=True, type=str, default='us', help='Amazon marketplace.')
@click.option('-o', '--output_path', required=True, type=str, help='Output file path')
@click.option('-so', '--source', required=True, type=str, help='Product source.')
@click.option('-sc', '--source_code', required=True, type=str, help='Product source code.')
@click.option('-e', '--export', is_flag=True, help='Whether to export products to other countries.')
@click.argument('products_path')
def filter_products(store_code, output_path, products_path, source, source_code, marketplace, export=False):
  init_db()

  if not products_path or not output_path:
    return

  products_path = os.path.abspath(os.path.expanduser(products_path))
  if not os.path.isfile(products_path):
    return

  output_path = os.path.abspath(os.path.expanduser(output_path))
  output_dir = os.path.dirname(output_path)
  if not os.path.isdir(output_dir):
    os.makedirs(output_dir)

  filter_cond = get_amz_offer_filter_config(marketplace)
  offer_service_cfg = get_offer_service_config()
  offer_service = AmzOfferService(
    offer_service_cfg['host'], offer_service_cfg['port'],
    offer_service_cfg['user'], offer_service_cfg['password'], filter_cond)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 4.5,
    'transfer_cost': 12
  }

  marketplace = marketplace.lower()
  cfg = get_config()
  price_rules_cfg = cfg.get('price.rules.amz_{}'.format(marketplace), dict())
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  product_service = get_product_service()

  filter_conds = None
  if export:
    filter_conds = {'export': export}

  products_filter = AmzUploadableProductsFormatter(
    store_code, marketplace, product_service, offer_service, price_calculator, output_path,
    products_path, source, source_code, filter_conds)

  products_filter.run()


if __name__ == "__main__":
  filter_products()
